@@ -51,13 +51,14 @@ class simple_discord_bot:
         except Exception as login_error:
             print(login_error)
 
-    def config(self, show_dms=False, status="online", activity=None, respond_to_other_bots=True):
+    def config(self, show_dms=False, status="online", activity=None, respond_to_other_bots=True, show_server_count=False):
 
         command_dict["config_options"] = {
             "show_dms": show_dms,
             "status": status,
             "activity": activity,
-            "respond_to_other_bots": respond_to_other_bots
+            "respond_to_other_bots": respond_to_other_bots,
+            "show_server_count": show_server_count
         }
         if status == "do not disturb":
             command_dict["config_options"]["status"] = "dnd"
@@ -65,6 +66,7 @@ class simple_discord_bot:
 
 @client.event
 async def on_ready():
+    server_count = 0
     print(f"Successfully logged in to Discord as user '{client.user}'")
     try:
         if command_dict["config_options"]["activity"] == None:
@@ -74,6 +76,13 @@ async def on_ready():
         await client.change_presence(status=command_dict["config_options"]["status"], activity=discord.Game(command_dict["config_options"]["activity"]))
     except KeyError:
         pass
+    
+    try:
+        if command_dict["config_options"]["show_server_count"] == True:
+            for x in client.guilds:
+                server_count += 1
+
+            print(f"Bot is in {server_count} servers.")
 
 
 @client.event
